@@ -60,7 +60,7 @@ module wt_module
   public wt_Potential2vector
   public wt_VGradV
   public wtBoundaries, wt_TorBoundaries, wz_LaplaPol2Pol_wz
-  public wt_PolmagBoundaries
+  public wt_TormagBoundaries, wt_PolmagBoundaries
 
   integer            :: im=64, jm=32, km=16  ! ʻ(, , ư)
   integer            :: nm=21, lm=16         ! ȿ(ʿ, ư)
@@ -757,6 +757,62 @@ module wt_module
 
     end function wz_LaplaPol2Pol_wz
 
+    subroutine wt_TormagBoundaries(wt_TOR) ! ȥݥƥ󥷥붭
+      ! Chebyshev ֤ǤζŬ
+      ! ȥݥƥ󥷥 \psi ζ(ŵƳ)
+      ! ¦
+      !    wt_psi = 0   at the outer boundary
+      ! ¦
+      !    wt_psi = 0       at the inner boundary
+      ! 
+      ! wtBoundaries ʣѿƱбƤʤΤ
+      ! ӺƤ
+
+      real(8), dimension((nm+1)*(nm+1),0:lm),intent(inout)   :: wt_TOR
+              ! ŬѤǡ. 줿֤ͤ. 
+
+      real(8), dimension(:,:,:), allocatable  :: alu
+      integer, dimension(:,:), allocatable    :: kp
+
+      real(8), dimension(:,:), allocatable    :: tt_I
+      real(8), dimension(:,:), allocatable    :: tz_PSI
+
+      logical :: first = .true.
+      integer  :: l, n
+      save     :: alu, kp, first
+
+      if ( first ) then
+         first = .false.
+
+         allocate(alu((nm+1)*(nm+1),0:lm,0:lm),kp((nm+1)*(nm+1),0:lm))
+         allocate(tt_I(0:lm,0:lm),tz_PSI(0:lm,0:km))
+
+         tt_I = 0.0
+         do l=0,lm
+            tt_I(l,l)=1
+         enddo
+         do n=1,(nm+1)*(nm+1)
+            alu(n,:,:) = tt_I
+         enddo
+
+         ! ŵƳ
+         tz_PSI = az_at(tt_I)
+
+         do n=1,(nm+1)*(nm+1)
+            alu(n,lm-1,:) = tz_PSI(:,0)
+            alu(n,lm,:)   = tz_PSI(:,km)
+         enddo
+         call ludecomp(alu,kp)
+
+         deallocate(tt_I,tz_PSI)
+      endif
+
+      wt_TOR(:,lm-1) = 0.0
+      wt_TOR(:,lm)   = 0.0
+      wt_TOR = lusolve(alu,kp,wt_TOR)
+
+    end subroutine wt_TormagBoundaries
+
     subroutine wt_PolmagBoundaries(wt_POL) ! ȥݥƥ󥷥붭
       ! Chebyshev ֤ǤζŬ
       ! ݥݥƥ󥷥 \psi ζ(ŵƳ)
